@@ -33,12 +33,13 @@ aspell --check "manual/en/${FILE}" --dont-backup --lang="en"
 List_files ()
 {
 ls manual/en | cat --number
+printf "\tdebian/changelog"
 }
 
 Select_files ()
 {
 echo ""
-echo "Choose a number ['a' to see all] or ['q' to quit]:"
+echo "Choose a number ['a' to see all] ['c' for changelog] or ['q' to quit]:"
 
 read NUMBER
 
@@ -57,7 +58,13 @@ case "$NUMBER" in
 				Check_file
 			done
 		;;
-
+    
+	c) 
+		echo "Checking spelling in debian/changelog"
+		sleep 2
+		aspell --check "debian/changelog" --dont-backup --lang="en"
+		;;
+        
 	q)	
 		exit 0 
 		;;
